Creates a data frame containing collective anomaly locations, lags and changes in mean and variance as detected by
capa.uv, capa.mv, and capa.
For an object produced by capa.uv, collective_anomalies returns a data frame with columns containing the start and end position of the anomaly, the change in mean
due to the anomaly. When type="meanvar", the change in variance due to the anomaly is also returned in an additional column.
For an object produced by capa.mv, collective_anomalies returns a data frame with columns containing the start and end position of the anomaly, the variates
affected by the anomaly, as well as their the start and end lags. When type="mean" only the change in mean is reported. When type="meanvar" both the change in mean and
change in variance are included. If merged=FALSE (the default), then all the collective anomalies are processed individually even if they are common across multiple variates.
If merged=TRUE, then the collective anomalies are grouped together across all variates that they appear in.
For an object produced by capa, collective_anomalies returns the same results as capa.uv when the data is univariate, or the same results as
capa.mv when the data is multivariate.
# S4 method for capa.class
collective_anomalies(object, merged = FALSE)# S4 method for capa.uv.class
collective_anomalies(object)
# S4 method for capa.mv.class
collective_anomalies(object)
Boolean value. If merged=TRUE then collective anomalies that are common across multiple variates are merged together. This is useful when comparing the relative strength
of multivariate collective anomalies. Default value is merged=FALSE. Note - merged=TRUE is currently only available when type="mean".
A data frame.