Creates a data frame containing point anomaly locations and strengths as detected by capa, capa.uv, and capa.mv.
For an object produced by capa.uv, the output is a data frame with columns containing the position and
strength of the anomaly.
For an object produced by capa.mv, point_anomalies returns a data frame with columns containing the position, variate, and
strength of the anomaly.
For an object produced by capa, point_anomalies returns the same results as capa.uv when the data is univariate, and the same results as
capa.uv when the data is multivariate.
# S4 method for capa.class
point_anomalies(object)# S4 method for capa.uv.class
point_anomalies(object)
# S4 method for capa.mv.class
point_anomalies(object)
A data frame.